# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: temporal/api/version/v1/message.proto
# plugin: python-betterproto
from dataclasses import dataclass

import betterproto


@dataclass
class SupportedSDKVersions(betterproto.Message):
    """SupportedSDKVersions contains the support versions for SDK."""

    go_sdk: str = betterproto.string_field(1)
    java_sdk: str = betterproto.string_field(2)


@dataclass
class WorkerVersionInfo(betterproto.Message):
    implementation: str = betterproto.string_field(1)
    feature_version: str = betterproto.string_field(2)
